benzene: Generate fusenes and benzenoids with a given number of faces
=====================================================================

Description
-----------

Benzene is a program for the efficient generation of all nonisomorphic
fusenes and benzenoids with a given number of faces. Fusenes are planar
polycyclic hydrocarbons with all bounded faces hexagons. Benzenoids are
fusenes that are subgraphs of the hexagonal lattice.

License
-------

Benzene is licensed under the GNU General Public License v2 or later
(June 2007)


Upstream Contact
----------------

Benzene was written by Gunnar Brinkmann and Gilles Caporossi. This
version was adapted by Gunnar Brinkmann and Nico Van Cleemput for
Grinvin.

http://www.grinvin.org/
